Name:           vim-perl-support
Version:        4.1
Release:        2%{?dist}
Summary:        Perl-IDE for VIM

Group:          Applications/Editors
# according to plugin/perl-support.vim
License:        GPLv2
URL:            http://www.vim.org/scripts/script.php?script_id=556
# curl -o perl-support.zip 'http://www.vim.org/scripts/download_script.php?src_id=10227'
Source0:        perl-support.zip
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

BuildArch:      noarch

Requires:         vim-enhanced
Requires(post):   vim-enhanced
Requires(postun): vim-enhanced

# optional requirements
# Critique Perl source code for best-practices
Requires:         perl(Perl::Critic)         
# Parses and beautifies perl source
Requires:         perl(Perl::Tidy)           
# per-line Perl profiler
Requires:         perl(Devel::SmallProf)     
# Powerful feature-rich perl source code profiler
Requires:         perl(Devel::NYTProf)

# the following are not yet available in fedora
# Perl debugger using a Tk GUI
#Requires:         perl(Devel::ptkdb)         
# Generate Ctags style tags for Perl source code
#Requires:         perl(Perl::Tags)           
# regular expression analyzer
#Requires:         perl(YAPE::Regex::Explain) 
# additional profilers
#Requires:         perl(Devel::FastProf)


%define vimfiles  %{_datadir}/vim/vimfiles

%description
Perl Support implements a Perl-IDE for Vim/gVim. It is written to considerably
speed up writing code in a consistent style.  This is done by inserting
complete statements, comments, idioms, code snippets, templates, and POD
documentation.  Reading perldoc is integrated.  Syntax checking, running a
script, running perltidy,  running perlcritics, starting a debugger and a
profiler can be done with a keystroke.


%prep
%setup -q -c

# strip out false provides/requires from codesnippets
cat << \EOF > %{name}-prov
#!/bin/sh
%{__perl_provides} $* |\
sed -re '/perl\((Class|Package)Name/d'
EOF
%define __perl_provides %{_builddir}/%{name}-%{version}/%{name}-prov
chmod +x %{__perl_provides}

cat << \EOF > %{name}-req
#!/bin/sh
%{__perl_requires} $* |\
sed -re '/perl\((Class|base)/d'
EOF
%define __perl_requires %{_builddir}/%{name}-%{version}/%{name}-req
chmod +x %{__perl_requires}


%build
# build is empty


%install
rm -rf %{buildroot}
install -m 755 -d %{buildroot}%{vimfiles}/autoload
install -m 644 -p autoload/*.vim %{buildroot}%{vimfiles}/autoload
install -m 755 -d %{buildroot}%{vimfiles}/doc
install -m 644 -p doc/*.txt %{buildroot}%{vimfiles}/doc
install -m 755 -d %{buildroot}%{vimfiles}/ftplugin
install -m 644 -p ftplugin/*.vim %{buildroot}%{vimfiles}/ftplugin
install -m 755 -d %{buildroot}%{vimfiles}/plugin
install -m 644 -p plugin/*.vim %{buildroot}%{vimfiles}/plugin
install -m 755 -d %{buildroot}%{vimfiles}/perl-support/codesnippets
install -m 644 -p perl-support/codesnippets/* \
    %{buildroot}%{vimfiles}/perl-support/codesnippets
install -m 755 -d %{buildroot}%{vimfiles}/perl-support/templates
install -m 644 -p perl-support/templates/* \
    %{buildroot}%{vimfiles}/perl-support/templates
install -m 755 -d %{buildroot}%{vimfiles}/perl-support/modules
install -m 644 -p perl-support/modules/* \
    %{buildroot}%{vimfiles}/perl-support/modules
install -m 755 -d %{buildroot}%{vimfiles}/perl-support/scripts
install -m 755 -p perl-support/scripts/*.{pl,sh} \
    %{buildroot}%{vimfiles}/perl-support/scripts
install -m 644 -p perl-support/scripts/*.vim \
    %{buildroot}%{vimfiles}/perl-support/scripts
install -m 755 -d %{buildroot}%{vimfiles}/perl-support/wordlists
install -m 644 -p perl-support/wordlists/* \
    %{buildroot}%{vimfiles}/perl-support/wordlists

%clean
rm -rf %{buildroot}


%post
umask 022
cd %{_datadir}/vim/vimfiles/doc
vim -u NONE -esX -c "helptags ." -c quit
exit 0


%postun
if [ $1 -eq 0 ]; then
   umask 022
   cd %{_datadir}/vim/vimfiles/doc
   >tags
   vim -u NONE -esX -c "helptags ." -c quit
fi
exit 0


%files
%defattr(-,root,root,-)
%doc README.perlsupport perl-support/doc/* perl-support/rc
%{vimfiles}/perl-support
%{vimfiles}/autoload/*.vim
%{vimfiles}/doc/perlsupport.txt
%{vimfiles}/ftplugin/perl.vim
%{vimfiles}/plugin/perl-support.vim


%changelog
* Mon Apr 13 2009 Iain Arnell <iarnell@gmail.com> 4.1-2
- require perl(Devel::NYTProf) now that it's available

* Tue Mar 17 2009 Iain Arnell <iarnell@gmail.com> 4.1-1
- update to latest upstream version

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 24 2009 Iain Arnell <iarnell@gmail.com> 4.0.1-2
- require perl(Devel::SmallProf) now that it's available

* Fri Jan 02 2009 Iain Arnell <iarnell@gmail.com> 4.0.1-1
- Bugfix: Error message in some functions that issue a prompt.

* Fri Jan 02 2009 Iain Arnell <iarnell@gmail.com> 4.0-1
- update to 4.0:
 + Completely new template system. Most menu items now user definable.
 + Plugin split into autoloadable modules (makes Vim startup faster).
 + Submenus for perlcritic severity and verbosity.
 In consequence there are some obsolete files and global variables, and some
 new files and hotkeys.
- fix bug in Perl_Input function

* Fri Nov 28 2008 Iain Arnell <iarnell@gmail.com> 3.9.1-1
- create vim-perl-support
